# [pynex](https://github.com/Pixelsuft/pynex/)
PyGame based GUI Library
## Screenshots
[![Screenshot1](https://user-images.githubusercontent.com/68371847/159104352-ae9db05a-81ef-443b-ad7e-cc889e8c1174.png)](https://github.com/Pixelsuft/pynex)
## Install
On Windows:
```sh
python -m pip install pynex
```
On Linux:
```sh
python3 -m pip install pynex
```
## Links
[Readme](https://github.com/Pixelsuft/pynex/blob/main/README.MD) <br />
[Example](https://github.com/Pixelsuft/pynex/blob/main/main.py) <br />
[Issue tracker](https://github.com/Pixelsuft/pynex/issues)
